==> Ryacas_0.2-6.tar.gz: Ryacas/inst/doc/Ryacas.R <==
###################################################
### chunk number 1: 
###################################################
library(Ryacas)
options(width=60)


###################################################
### chunk number 2: 
###################################################
yacas(expression((10 + 2) * 5 + 7^7))
yacas(expression(1/14+5/21*(30-(1+1/2)*5^2)))


###################################################
### chunk number 3: 
###################################################
yacas(expression(N(-12/2)))


###################################################
### chunk number 4: 
###################################################
yacas(expression(Factor(x^2-1)))
exp1 <- expression(x^2 + 2 * x^2)
exp2 <- expression(2 * exp0)
exp3 <- expression(6 * pi * x)
exp4 <- expression((exp1 * (1 - sin(exp3))) / exp2)
yacas(exp4)


###################################################
### chunk number 5: 
###################################################
yacas("N(Sin(1)^2 + Cos(x)^2)")
yacas("N(Sin(1)^2 + Cos(x)^2)", retclass="character")


###################################################
### chunk number 6: 
###################################################
yacas("D(x)Sin(x)")


###################################################
### chunk number 7: 
###################################################
yacas("A")
yacas("A:='ssss'")
yacas("a")
yacas("Integrate(x,a,b)Sin(x)")
yacas("Clear(A)")
yacas("A")
yacas("Integrate(x,a,b)Sin(x)")


###################################################
### chunk number 8: 
###################################################
yacas("Expand((1+x)^3)")


###################################################
### chunk number 9: 
###################################################
yacas("texp := Taylor(x,0,3) Exp(x)")


###################################################
### chunk number 10: 
###################################################
yacas("PrettyForm(texp)") 
yacas("TeXForm(texp)", retclass = "unquote")


###################################################
### chunk number 11: 
###################################################
yacas("n := (10 + 2) * 5")
yacas("n := n+n")
yacas("Set(z, Cos(a))")
yacas("z+z")


###################################################
### chunk number 12: 
###################################################
yacas(expression(n))
yacas("Clear(n)")
yacas(expression(n))


###################################################
### chunk number 13: 
###################################################
yacas("Exp(0)")
yacas("Exp(1)")
yacas("Sin(Pi/4)")
yacas("355/113")


###################################################
### chunk number 14: 
###################################################
yacas("N(Exp(1))")
yacas("N(Sin(Pi/4))")
yacas("N(355/113)")


###################################################
### chunk number 15: 
###################################################
yacas("N(355/133,20)")


###################################################
### chunk number 16: 
###################################################
yacas("Precision(5)")
yacas("N(355/113)")


###################################################
### chunk number 17: 
###################################################
yacas(expression(55/10))


###################################################
### chunk number 18: 
###################################################
yacas("1/14+5/21*(30-(1+1/2)*5^2)")
yacas("0+x")
yacas("x+1*y")
yacas("Sin(ArcSin(alpha))+Tan(ArcTan(beta))")


###################################################
### chunk number 19: 
###################################################
yacas("I^2")
yacas("7+3*I")
yacas("Conjugate(%)")
yacas("Exp(3*I)")


###################################################
### chunk number 20: 
###################################################
yacas("(1+x)^3")
yacas("%")
yacas("z:= %")


###################################################
### chunk number 21: 
###################################################
yacas("A:={{a,b},{c,d}}")
yacas("B:= (1+x)^2+k^3")
yacas("A")
yacas("B")


###################################################
### chunk number 22: 
###################################################
yacas("PrettyForm(A)")
yacas("PrettyForm(B)")


###################################################
### chunk number 23: 
###################################################
yacas('PrettyPrinter("PrettyForm")')
yacas("A")
yacas('PrettyPrinter()')
yacas("A")


###################################################
### chunk number 24: 
###################################################
yacas("TeXForm(B)")
yacas("TexForm(B)")


###################################################
### chunk number 25: 
###################################################
yacas("40!")


###################################################
### chunk number 26: 
###################################################
yacas("Taylor(x,0,3) Exp(x)")
yacas("Taylor(x,a,3) Exp(x)")


###################################################
### chunk number 27: 
###################################################
yacas("InverseTaylor(x,0,2)Exp(x)")
yacas("Taylor(y,1,2)Ln(y)")


###################################################
### chunk number 28: 
###################################################
yacas("Solve(x/(1+x) == a, x)")
yacas("Solve(x^2+x == 0, x)")


###################################################
### chunk number 29: 
###################################################
yacas("Newton(Sin(x)-Exp(x),x, 0.5, 0.0001)")


###################################################
### chunk number 30: 
###################################################
yacas("Expand((1+x)^3)")


###################################################
### chunk number 31: 
###################################################
yacas("(x+y)^3-(x-y)^3")
yacas("Simplify(%)")


###################################################
### chunk number 32: 
###################################################
yacas("D(x) Sin(x)")
yacas("D(x) D(x) Sin(x)")


###################################################
### chunk number 33: 
###################################################
yacas("D(x,2)Sin(x)")


###################################################
### chunk number 34: 
###################################################
yacas("Integrate(x,a,b)Sin(x)")
yacas("Integrate(x,a,b)Ln(x)+x")
yacas("Integrate(x)1/(x^2-1)")
yacas("Integrate(x)Sin(a*x)^2*Cos(b*x)")


###################################################
### chunk number 35: 
###################################################
yacas("Limit(x,0)Sin(x)/x")
yacas("Limit(n,Infinity)(1+(1/n))^n")
yacas("Limit(h,0) (Sin(x+h)-Sin(x))/h")


###################################################
### chunk number 36: 
###################################################
yacas("Subst(x,Cos(a))x+x")


###################################################
### chunk number 37: 
###################################################
yacas("OdeSolve(y''==4*y)")
yacas("OdeSolve(y'==8*y)")


###################################################
### chunk number 38: 
###################################################
yacas("E4:={ {u1,u1,0},{u1,0,u2},{0,u2,0} }")
yacas("PrettyForm(E4)")


###################################################
### chunk number 39: 
###################################################
yacas("E4i:=Inverse(E4)")
yacas("Simplify(E4i)")
yacas("PrettyForm(Simplify(E4i))")


###################################################
### chunk number 40: 
###################################################
yacas("Determinant(E4)")
yacas("Determinant(E4i)")
yacas("Simplify(E4i)")
yacas("Simplify(Determinant(E4i))")

==> Ryacas_0.3-4.tar.gz: Ryacas/inst/doc/Ryacas.R <==
### R code from vignette source 'Ryacas.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: Ryacas.Rnw:54-56
###################################################
library(Ryacas)
options(width=95)


###################################################
### code chunk number 2: Ryacas.Rnw:104-105
###################################################
exp1 <- yacas(expression(Factor(x^2-1)))


###################################################
### code chunk number 3: Ryacas.Rnw:112-113
###################################################
Eval(exp1, list(x=4))


###################################################
### code chunk number 4: Ryacas.Rnw:127-128
###################################################
yacas("D(x)Sin(x)")


###################################################
### code chunk number 5: Ryacas.Rnw:144-145
###################################################
x <- Sym("x")


###################################################
### code chunk number 6: Ryacas.Rnw:150-151
###################################################
x+4


###################################################
### code chunk number 7: Ryacas.Rnw:157-158
###################################################
Integrate(sin(x), x)


###################################################
### code chunk number 8: Ryacas.Rnw:165-169
###################################################
x <- Sym("xs")
x
x+4
Eval(x+4, list(xs=5))


###################################################
### code chunk number 9: Ryacas.Rnw:175-176
###################################################
xs <- Sym('xs')


###################################################
### code chunk number 10: Ryacas.Rnw:185-187
###################################################
yacas(expression((10 + 2) * 5 + 7^7))
yacas(expression(1/14+5/21* (30- 1+ 1/2)))


###################################################
### code chunk number 11: Ryacas.Rnw:191-196
###################################################
#(Sym(10) + Sym(2)) * Sym(5) + Sym(7) ^ Sym(7)
Sym("10 * 2") * 5 + Sym(7) ^ 7
#(Sym(10) + 2) * 5 + Sym(7) ^ 7
#Sym("(10+2)*5 + 7^7")
Sym("1/14 + 5/21 * (30 - 1+1/2)")


###################################################
### code chunk number 12: Ryacas.Rnw:202-203
###################################################
yacas(expression(N(-12/2)))


###################################################
### code chunk number 13: Ryacas.Rnw:206-208
###################################################
Sym("-12/2")
#Eval(Sym("-12/2"))


###################################################
### code chunk number 14: Ryacas.Rnw:213-219
###################################################
yacas(expression(Factor(x^2-1)))
exp1 <- expression(x^2 + 2 * x^2)
exp2 <- expression(2 * exp0)
exp3 <- expression(6 * pi * x)
exp4 <- expression((exp1 * (1 - sin(exp3))) / exp2)
yacas(exp4)


###################################################
### code chunk number 15: Ryacas.Rnw:223-230
###################################################
Factor(xs^2-1)
exp1 <- xs^2 + 2 * xs^2
exp0 <- Sym("exp0")
exp2 <- 2 * Sym(exp0)
exp3 <- 6 * Pi * xs
exp4 <- exp1 * (1 - sin(exp3)) / exp2
exp4


###################################################
### code chunk number 16: Ryacas.Rnw:237-238
###################################################
yacas(expression(N(Sin(1)^2 + Cos(x)^2)))


###################################################
### code chunk number 17: Ryacas.Rnw:242-243
###################################################
N(sin(1)^2 + cos(xs)^2)


###################################################
### code chunk number 18: Ryacas.Rnw:248-249
###################################################
yacas("D(x)Sin(x)")


###################################################
### code chunk number 19: Ryacas.Rnw:252-253
###################################################
deriv(sin(xs), xs)


###################################################
### code chunk number 20: Ryacas.Rnw:258-259
###################################################
yacas("Clear(a,b,A,B)")


###################################################
### code chunk number 21: Ryacas.Rnw:263-264
###################################################
yacas("Integrate(x,a,b)Sin(x)")


###################################################
### code chunk number 22: Ryacas.Rnw:268-271
###################################################
as <- Sym("as")
bs <- Sym("bs")
Integrate(sin(xs), xs, as, bs)


###################################################
### code chunk number 23: Ryacas.Rnw:277-278
###################################################
yacas("Expand((1+x)^3)")


###################################################
### code chunk number 24: Ryacas.Rnw:282-283
###################################################
Expand((1+xs)^3)


###################################################
### code chunk number 25: Ryacas.Rnw:288-289
###################################################
yacas("texp := Taylor(x,0,3) Exp(x)")


###################################################
### code chunk number 26: Ryacas.Rnw:293-294
###################################################
texp <- Taylor(exp(xs), xs, 0, 3)


###################################################
### code chunk number 27: Ryacas.Rnw:300-302
###################################################
yacas("PrettyForm(texp)") 
yacas("TeXForm(texp)", retclass = "unquote")


###################################################
### code chunk number 28: Ryacas.Rnw:306-308
###################################################
PrettyForm(texp) 
TeXForm(texp)


###################################################
### code chunk number 29: Ryacas.Rnw:321-325
###################################################
yacas("n := (10 + 2) * 5")
yacas("n := n+n")
#yacas("Set(z, Cos(a))")
#yacas("z+z")


###################################################
### code chunk number 30: Ryacas.Rnw:330-331
###################################################
Set(ns, (10 + 2) * 5)


###################################################
### code chunk number 31: Ryacas.Rnw:339-340
###################################################
ns <- Sym("ns")


###################################################
### code chunk number 32: Ryacas.Rnw:345-348
###################################################
Set(ns,123)
ns
ns^2


###################################################
### code chunk number 33: Ryacas.Rnw:353-357
###################################################
as <- Sym("as")
zs <- Sym("zs")
Set(zs, cos(as))
zs + zs


###################################################
### code chunk number 34: Ryacas.Rnw:364-367
###################################################
yacas(expression(n))
yacas("Clear(n)")
yacas(expression(n))


###################################################
### code chunk number 35: Ryacas.Rnw:371-376
###################################################
Set(ns, 1)
ns <- Sym("ns")
ns
Clear(ns)
ns


###################################################
### code chunk number 36: Ryacas.Rnw:384-388
###################################################
yacas("Exp(0)")
yacas("Exp(1)")
yacas("Sin(Pi/4)")
yacas("355/113")


###################################################
### code chunk number 37: Ryacas.Rnw:392-396
###################################################
exp(Sym(0))
exp(Sym(1))
sin(Pi/4)
Sym("355/113")


###################################################
### code chunk number 38: Ryacas.Rnw:402-405
###################################################
yacas("N(Exp(1))")
yacas("N(Sin(Pi/4))")
yacas("N(355/113)")


###################################################
### code chunk number 39: Ryacas.Rnw:409-412
###################################################
N(exp(1))
N(sin(Pi/4))
N(355/113)


###################################################
### code chunk number 40: Ryacas.Rnw:417-418
###################################################
yacas("N(355/133,20)")


###################################################
### code chunk number 41: Ryacas.Rnw:422-423
###################################################
N("355/113",20) 


###################################################
### code chunk number 42: Ryacas.Rnw:431-433
###################################################
yacas("Precision(5)")
yacas("N(355/113)")


###################################################
### code chunk number 43: Ryacas.Rnw:437-439
###################################################
Precision(5)
N("355/113")


###################################################
### code chunk number 44: Ryacas.Rnw:448-449
###################################################
yacas(expression(55/10))


###################################################
### code chunk number 45: Ryacas.Rnw:453-454
###################################################
Sym("55 / 10")


###################################################
### code chunk number 46: Ryacas.Rnw:463-467
###################################################
yacas("1/14+5/21*(30-(1+1/2)*5^2)")
yacas("0+x")
yacas("x+1*y")
yacas("Sin(ArcSin(alpha))+Tan(ArcTan(beta))")


###################################################
### code chunk number 47: Ryacas.Rnw:471-477
###################################################
Sym("1/14+5/21*(1*30-(1+1/2)*5^2)")
xs <- Sym("xs")
ys <- Sym("ys")
0+xs
xs+1*ys
sin(asin(xs))+tan(atan(ys))


###################################################
### code chunk number 48: Ryacas.Rnw:485-489
###################################################
yacas("I^2")
yacas("7+3*I")
yacas("Conjugate(%)")
yacas("Exp(3*I)")


###################################################
### code chunk number 49: Ryacas.Rnw:493-497
###################################################
I^2
7+3*I
Conjugate(7+3*I)
exp(3*I)


###################################################
### code chunk number 50: Ryacas.Rnw:506-509
###################################################
yacas("(1+x)^3")
yacas("%")
yacas("z:= %")


###################################################
### code chunk number 51: Ryacas.Rnw:513-516
###################################################
(1+x)^3
zs <- Sym("%")
zs


###################################################
### code chunk number 52: Ryacas.Rnw:531-535
###################################################
yacas("A:={{a,b},{c,d}}")
yacas("B:= (1+x)^2+k^3")
yacas("A")
yacas("B")


###################################################
### code chunk number 53: Ryacas.Rnw:539-545
###################################################
as <- Sym("as"); bs <- Sym("bs"); cs <- Sym("cs"); ds <- Sym("ds")
A <- List(List(as,bs), List(cs,ds))
ks <- Sym("ks")
B <- (1+xs)^2+ks^3
A
B


###################################################
### code chunk number 54: Ryacas.Rnw:552-554
###################################################
yacas("PrettyForm(A)")
yacas("PrettyForm(B)")


###################################################
### code chunk number 55: Ryacas.Rnw:558-560
###################################################
PrettyForm(A)
PrettyForm(B)


###################################################
### code chunk number 56: Ryacas.Rnw:569-571
###################################################
#FIXME
#yacas("TeXForm(B)")


###################################################
### code chunk number 57: Ryacas.Rnw:575-577
###################################################
#FIXME
#TeXForm(B)


###################################################
### code chunk number 58: Ryacas.Rnw:588-589
###################################################
yacas("40!")


###################################################
### code chunk number 59: Ryacas.Rnw:593-594
###################################################
Factorial(40)


###################################################
### code chunk number 60: Ryacas.Rnw:602-604
###################################################
yacas("Taylor(x,0,3) Exp(x)")
yacas("Taylor(x,a,3) Exp(x)")


###################################################
### code chunk number 61: Ryacas.Rnw:608-612
###################################################
xs <- Sym("xs")
Taylor(exp(xs),xs,0,3)
as <- Sym("as")
Taylor(exp(x),x,as,3)


###################################################
### code chunk number 62: Ryacas.Rnw:620-622
###################################################
yacas("InverseTaylor(x,0,2)Exp(x)")
yacas("Taylor(y,1,2)Ln(y)")


###################################################
### code chunk number 63: Ryacas.Rnw:626-628
###################################################
InverseTaylor(exp(xs),xs,0,2)
Taylor(log(ys),ys,1,2)


###################################################
### code chunk number 64: Ryacas.Rnw:638-640
###################################################
yacas("Solve(x/(1+x) == a, x)")
yacas("Solve(x^2+x == 0, x)")


###################################################
### code chunk number 65: Ryacas.Rnw:643-645
###################################################
Solve(xs/(1+xs) == as, xs)
Solve(xs^2+xs == 0, xs)


###################################################
### code chunk number 66: Ryacas.Rnw:648-649
###################################################
Solve(List(xs^2+ys^2==6, xs-ys==3), List(xs,ys))


###################################################
### code chunk number 67: Ryacas.Rnw:652-655
###################################################
# FIXME
#Solve(List(mean==(xs/(xs+ys)), variance==((xs*ys)/(((xs+ys)^2) * (xs+ys+1)))),
#    List(xs,ys))


###################################################
### code chunk number 68: Ryacas.Rnw:665-666
###################################################
yacas("Newton(Sin(x)-Exp(x),x, 0.5, 0.0001)")


###################################################
### code chunk number 69: Ryacas.Rnw:670-671
###################################################
Newton(sin(xs)-exp(xs),xs, 0.5, 0.0001) 


###################################################
### code chunk number 70: Ryacas.Rnw:676-677
###################################################
yacas(expression(Expand((1+x)^3)))


###################################################
### code chunk number 71: Ryacas.Rnw:681-682
###################################################
Expand((x+1)^3)


###################################################
### code chunk number 72: Ryacas.Rnw:692-696
###################################################
y <- Sym("y")
yacas("(x+y)^3-(x-y)^3")
yacas("Simplify(%)")



###################################################
### code chunk number 73: Ryacas.Rnw:700-702
###################################################
(x+y)^3-(x-y)^3
Simplify("%")


###################################################
### code chunk number 74: Ryacas.Rnw:711-712
###################################################
yacas("D(x) Sin(x)")


###################################################
### code chunk number 75: Ryacas.Rnw:716-717
###################################################
deriv(sin(xs), xs)


###################################################
### code chunk number 76: Ryacas.Rnw:723-724
###################################################
yacas("D(x,4)Sin(x)")


###################################################
### code chunk number 77: Ryacas.Rnw:728-729
###################################################
deriv(sin(xs),xs,4)


###################################################
### code chunk number 78: Ryacas.Rnw:735-736
###################################################
yacas("Clear(a,b,A,B)")


###################################################
### code chunk number 79: Ryacas.Rnw:740-744
###################################################
#yacas("Integrate(x,a,b)Sin(x)")
#yacas("Integrate(x,a,b)Ln(x)+x")
#yacas("Integrate(x)1/(x^2-1)")
yacas("Integrate(x)Sin(a*x)^2*Cos(b*x)")


###################################################
### code chunk number 80: Ryacas.Rnw:748-754
###################################################
#Integrate(sin(x),x,a,b)
#Integrate(log(x),x,a,b)
#Integrate(1/(x^2-1),x)
a <- Sym("a")
b <- Sym("b")
Integrate(sin(a*x)^2*cos(b*x),x)


###################################################
### code chunk number 81: Ryacas.Rnw:760-763
###################################################
#yacas("Limit(x,0)Sin(x)/x")
yacas("Limit(n,Infinity)(1+(1/n))^n")
yacas("Limit(h,0) (Sin(x+h)-Sin(x))/h")


###################################################
### code chunk number 82: Ryacas.Rnw:767-772
###################################################
#Limit(sin(x)/x,x,0)
ns <- Sym("ns")
Limit((1+(1/ns))^ns,ns,Infinity)
hs <- Sym("hs")
Limit((sin(xs+hs)-sin(xs))/hs,hs,0)


###################################################
### code chunk number 83: Ryacas.Rnw:778-779
###################################################
yacas("Subst(x,Cos(a))x+x")


###################################################
### code chunk number 84: Ryacas.Rnw:783-784
###################################################
Subst(xs+xs,xs,cos(as))


###################################################
### code chunk number 85: Ryacas.Rnw:790-792
###################################################
yacas("OdeSolve(y''==4*y)")
yacas("OdeSolve(y'==8*y)")


###################################################
### code chunk number 86: Ryacas.Rnw:805-807
###################################################
yacas("E4:={ {u1,u1,0},{u1,0,u2},{0,u2,0} }")
yacas("PrettyForm(E4)")


###################################################
### code chunk number 87: Ryacas.Rnw:811-815
###################################################
u1 <- Sym("u1")
u2 <- Sym("u2")
E4 <- List(List(u1, u1, 0), List(u1, 0, u2), List(0, u2, 0))
PrettyForm(E4)


###################################################
### code chunk number 88: Ryacas.Rnw:822-825
###################################################
yacas("E4i:=Inverse(E4)")
yacas("Simplify(E4i)")
yacas("PrettyForm(Simplify(E4i))")


###################################################
### code chunk number 89: Ryacas.Rnw:830-833
###################################################
E4i <- Inverse(E4)
Simplify(E4i)
PrettyForm(Simplify(E4i))


###################################################
### code chunk number 90: Ryacas.Rnw:840-844
###################################################
yacas("Determinant(E4)")
yacas("Determinant(E4i)")
yacas("Simplify(E4i)")
yacas("Simplify(Determinant(E4i))")


###################################################
### code chunk number 91: Ryacas.Rnw:849-853
###################################################
determinant(E4)
determinant(E4i)
Simplify(E4i)
Simplify(determinant(E4i))


###################################################
### code chunk number 92: Ryacas.Rnw:866-868
###################################################
yacas(expression(Factor(x^2-1)),retclass='unquote')
yacas(expression(Factor(x^2-1)),retclass='character')
